/**
 * Copyright (C) 2008 Ovea <dev@testatoo.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.testatoo.container.impl;

import com.meterware.httpunit.WebConversation;
import com.meterware.httpunit.WebResponse;
import org.junit.Test;
import org.testatoo.container.Container;
import org.testatoo.container.ContainerConfiguration;
import org.testatoo.container.TestatooContainer;

import static org.hamcrest.Matchers.containsString;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertThat;
import static org.junit.Assert.assertTrue;

public final class JettyContainerTest {

    @Test
    public void test_toString() throws Exception {
        System.out.println(ContainerConfiguration.create()
                .port(9999)
                .webappRoot("../core/src/test/webapp")
                .context("superApp"));
        System.out.println(ContainerConfiguration.create()
                .port(9999)
                .webappRoot("../core/src/test/webapp")
                .context("superApp")
                .buildContainer(TestatooContainer.JETTY));
    }

    @Test
    public void test_html() throws Exception {
        Container container = ContainerConfiguration.create()
                .port(9999)
                .webappRoot("../core/src/test/webapp")
                .context("superApp")
                .buildContainer(TestatooContainer.JETTY);
        assertFalse(container.isRunning());
        container.start();
        assertTrue(container.isRunning());
        WebConversation wc = new WebConversation();
        WebResponse resp = wc.getResponse("http://127.0.0.1:9999/superApp/index.xhtml");
        assertEquals(resp.getTitle(), "HTML file");
        assertThat(resp.getText(), containsString("HTML file"));
        container.stop();
        assertFalse(container.isRunning());
    }

    @Test
    public void test_jsp() throws Exception {
        Container container = ContainerConfiguration.create()
                .port(9999)
                .webappRoot("../core/src/test/webapp")
                .context("superApp")
                .buildContainer(TestatooContainer.JETTY);
        assertFalse(container.isRunning());
        container.start();
        assertTrue(container.isRunning());
        WebConversation wc = new WebConversation();
        WebResponse resp = wc.getResponse("http://127.0.0.1:9999/superApp/index.jsp");
        assertEquals(resp.getTitle(), "JSP Test");
        assertThat(resp.getText(), containsString("Languages"));
        container.stop();
        assertFalse(container.isRunning());
    }

    @Test
    public void test_port() throws Exception {
        Container container = ContainerConfiguration.create()
                .port(9999)
                .webappRoot("../core/src/test/webapp")
                .context("superApp")
                .set("jetty.conf", "src/test/data/jetty-conf.xml")
                .set("jetty.trace", "true")
                .buildContainer(TestatooContainer.JETTY);
        assertEquals(container.port(), 6837);
        assertFalse(container.isRunning());
        container.start();
        assertTrue(container.isRunning());
        WebConversation wc = new WebConversation();
        WebResponse resp = wc.getResponse("http://127.0.0.1:6837/superApp/index.jsp");
        assertEquals(resp.getTitle(), "JSP Test");
        assertThat(resp.getText(), containsString("Languages"));
        container.stop();
        assertFalse(container.isRunning());
    }

    @Test
    public void test_jndi() throws Exception {
        Container container = ContainerConfiguration.create()
                .port(9999)
                .webappRoot("../core/src/test/webapp")
                .context("superApp")
                .buildContainer(TestatooContainer.JETTY);
        container.start();
        WebConversation wc = new WebConversation();
        WebResponse resp = wc.getResponse("http://127.0.0.1:9999/superApp/jndi.jsp");
        assertEquals(resp.getTitle(), "JNDI Test");
        assertThat(resp.getText(), containsString("OK"));
        container.stop();
    }

}
